@@ -4,6 +4,8 @@ Main file with the creation of the app logic
 
 # Full imports
 import os
+from logging.config import dictConfig
+
 import click
 
 # Partial imports
@@ -13,9 +15,8 @@ from flask_apispec.extension import FlaskApiSpec
 from flask_cors import CORS
 from flask_migrate import Migrate
 from flask_restful import Api
-from logging.config import dictConfig
-from werkzeug.middleware.dispatcher import DispatcherMiddleware
 from werkzeug.exceptions import NotFound
+from werkzeug.middleware.dispatcher import DispatcherMiddleware
 
 # Module imports
 from cornflow.commands import (
@@ -36,7 +37,14 @@ from cornflow.endpoints.login import LoginEndpoint, LoginOpenAuthEndpoint
 from cornflow.endpoints.signup import SignUpEndpoint
 from cornflow.shared import db, bcrypt
 from cornflow.shared.compress import init_compress
-from cornflow.shared.const import AUTH_DB, AUTH_LDAP, AUTH_OID
+from cornflow.shared.const import (
+    AUTH_DB,
+    AUTH_LDAP,
+    AUTH_OID,
+    CONDITIONAL_ENDPOINTS,
+    SIGNUP_WITH_AUTH,
+    SIGNUP_WITH_NO_AUTH,
+)
 from cornflow.shared.exceptions import initialize_errorhandlers, ConfigurationError
 from cornflow.shared.log_config import log_config
 
@@ -95,13 +103,21 @@ def create_app(env_name="development", dataconn=None):
 
     if auth_type == AUTH_DB:
         signup_activated = int(app.config["SIGNUP_ACTIVATED"])
-        if signup_activated == 1:
-            api.add_resource(SignUpEndpoint, "/signup/", endpoint="signup")
-        api.add_resource(LoginEndpoint, "/login/", endpoint="login")
+        if signup_activated in [SIGNUP_WITH_AUTH, SIGNUP_WITH_NO_AUTH]:
+            api.add_resource(
+                SignUpEndpoint, CONDITIONAL_ENDPOINTS["signup"], endpoint="signup"
+            )
+        api.add_resource(
+            LoginEndpoint, CONDITIONAL_ENDPOINTS["login"], endpoint="login"
+        )
     elif auth_type == AUTH_LDAP:
-        api.add_resource(LoginEndpoint, "/login/", endpoint="login")
+        api.add_resource(
+            LoginEndpoint, CONDITIONAL_ENDPOINTS["login"], endpoint="login"
+        )
     elif auth_type == AUTH_OID:
-        api.add_resource(LoginOpenAuthEndpoint, "/login/", endpoint="login")
+        api.add_resource(
+            LoginOpenAuthEndpoint, CONDITIONAL_ENDPOINTS["login"], endpoint="login"
+        )
     else:
         raise ConfigurationError(
             error="Invalid authentication type",
@@ -164,7 +180,7 @@ def create_base_user(username, email, password, verbose):
 @click.option("-v", "--verbose", is_flag=True, default=False)
 @with_appcontext
 def register_roles(verbose):
-    register_roles_command(verbose)
+    register_roles_command(verbose=verbose)
 
 
 @click.command("register_actions")
